#
# spec file for package sampler
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true
# Project name when using go tooling.
%define project github.com/sqshq/sampler
# Project upstream commit.
%define commit a086d99
Name:           sampler
Version:        1.1.0
Release:        2.19
Summary:        A tool for shell commands execution, visualization and alerting
License:        GPL-3.0-only
URL:            https://sampler.dev/
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  fdupes
BuildRequires:  go >= 1.11
BuildRequires:  go-md2man
BuildRequires:  pkgconfig(alsa)
ExcludeArch:    s390

%description
Sampler is a tool for shell commands execution, visualization and alerting. Configured with a simple YAML file.

%prep
%setup -q
%setup -q -T -D -a 1

%build
export VERSION=%{version}
export COMMIT=%{commit}
export CGO_ENABLED=1
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags "-s -w -X main.gitCommit=$COMMIT -X main.version=$VERSION" \
   -o %{name} ;

%install
# Install the binary.
install -D -m 0755 %{name} "%{buildroot}/%{_bindir}/%{name}"
# Build the man page.
go-md2man -in README.md -out %{name}.1

# Install the man page.
install -D -m 0644 %{name}.1 "%{buildroot}/%{_mandir}/man1/%{name}.1"
rm %{name}.1

%fdupes %{buildroot}

%files
%license LICENSE.md
%doc README.md
%{_bindir}/%{name}
%{_mandir}/man1/%{name}*.1.gz

%changelog
* Thu Dec  3 2020 Jeff Kowalczyk <jkowalczyk@suse.com>
- Remove unused BuildRequires: golang-github-kr-pty and golang-packaging
  * github.com/kr/pty already vendored via obs-service-go_modules
  * golang-packaging currently not needed for apps using go modules
* Wed Dec  2 2020 Richard Brown <rbrown@suse.com>
- Build on s390x
* Wed Dec 25 2019 dead_mozay@opensuse.org
- Update to version 1.1.0:
  * Update FUNDING.yml
  * Remove metadata storage (used for statistics and licensing)
  * Fix ticker rate issue
  * Update README.md
  * Remove all backend interaction
  * Cast rateMs when calculating NewTicker duration to avoid overflow on Raspberry PI
  * test(data): add tests for data/consumer
  * test(util): add tests for util/geometry
  * Update formatting
  * Update README.md
  * DOC: removes comments from constants
  * DOC: adds doc comments to exported functions
  * DOC: adds descriptive comments to exported types and functions
  * WIP: console package tests (palette)
  * WIP: console package tests (palette)
  * fix gauge percentage calculation for the case when min value is not zero
  * support newlines in asciibox
  * cleanup escape codes for regular and interactive shell sampling
* Tue Oct  1 2019 dead_mozay@opensuse.org
- Update to version 1.0.3:
  * Fix triggers functionality for textboxes and asciiboxes
  * Update README.md
  * Update README.md
  * Update README.md
  * Update README.md
  * Update README.md
  * support and assistance text added
  * added sudo
  * README and status bar text update for 1.0.2
* Mon Sep 30 2019 Dead Mozay <dead_mozay@opensuse.org>
- Initial package
